@@ -1,5 +1,5 @@
 /*
- * Copyright (C) 2013, 2015, 2016 Graeme Gott <graeme@gottcode.org>
+ * Copyright (C) 2013, 2015, 2016, 2017, 2018, 2019 Graeme Gott <graeme@gottcode.org>
  *
  * This library is free software; you can redistribute it and/or modify
  * it under the terms of the GNU General Public License as published by
@@ -40,6 +40,7 @@ enum
 {
 	STATUS_INVALID,
 	STATUS_LOADING,
+	STATUS_LOADING_RELOAD,
 	STATUS_LOADED
 };
 
@@ -156,25 +157,43 @@ void ApplicationsPage::apply_filter(GtkToggleButton* togglebutton)
 
 void ApplicationsPage::invalidate_applications()
 {
-	m_load_status = STATUS_INVALID;
+	if (m_load_status == STATUS_LOADED)
+	{
+		m_load_status = STATUS_INVALID;
+		clear_applications();
+	}
+	else if (m_load_status == STATUS_LOADING)
+	{
+		m_load_status = STATUS_LOADING_RELOAD;
+	}
 }
 
 //-----------------------------------------------------------------------------
 
-void ApplicationsPage::load_applications()
+bool ApplicationsPage::load_applications()
 {
 	// Check if already loaded
 	if (m_load_status == STATUS_LOADED)
 	{
-		return;
+		return true;
+	}
+	// Check if currently loading
+	else if ((m_load_status == STATUS_LOADING) || (m_load_status == STATUS_LOADING_RELOAD))
+	{
+		return false;
 	}
 	m_load_status = STATUS_LOADING;
 
 	// Load menu
 	clear_applications();
-	load_contents();
 
-	return;
+	// Load contents in thread if possible
+	GTask* task = g_task_new(NULL, NULL, &ApplicationsPage::load_contents_slot, this);
+	g_task_set_task_data(task, this, NULL);
+	g_task_run_in_thread(task, &ApplicationsPage::load_garcon_menu_slot);
+	g_object_unref(task);
+
+	return false;
 }
 
 //-----------------------------------------------------------------------------
@@ -225,7 +244,7 @@ void ApplicationsPage::clear_applications()
 
 //-----------------------------------------------------------------------------
 
-void ApplicationsPage::load_contents()
+void ApplicationsPage::load_garcon_menu()
 {
 	// Create menu
 	if (wm_settings->custom_menu_file.empty())
@@ -246,7 +265,6 @@ void ApplicationsPage::load_contents()
 
 	if (!m_garcon_menu)
 	{
-		m_load_status = STATUS_INVALID;
 		return;
 	}
 
@@ -287,10 +305,24 @@ void ApplicationsPage::load_contents()
 	}
 	category->sort();
 	m_categories.insert(m_categories.begin(), category);
+}
+
+//-----------------------------------------------------------------------------
+
+void ApplicationsPage::load_contents()
+{
+	if (!m_garcon_menu)
+	{
+		get_window()->set_loaded();
+
+		m_load_status = STATUS_INVALID;
+
+		return;
+	}
 
 	// Set all applications category
 	get_view()->set_fixed_height_mode(true);
-	get_view()->set_model(category->get_model());
+	get_view()->set_model(m_categories.front()->get_model());
 
 	// Add buttons for categories
 	std::vector<SectionButton*> category_buttons;
@@ -306,8 +338,17 @@ void ApplicationsPage::load_contents()
 
 	// Update menu items of other panels
 	get_window()->set_items();
+	get_window()->set_loaded();
 
-	m_load_status = STATUS_LOADED;
+	if (m_load_status == STATUS_LOADING)
+	{
+		m_load_status = STATUS_LOADED;
+	}
+	else
+	{
+		m_load_status = STATUS_INVALID;
+		clear_applications();
+	}
 }
 
 //-----------------------------------------------------------------------------
