@@ -57,6 +57,22 @@ static void whiskermenu_config_dialog_delete(ConfigurationDialog* dialog)
 
 //-----------------------------------------------------------------------------
 
+static GtkWidget* make_aligned_frame(const gchar* label, GtkWidget* content)
+{
+	GtkWidget* alignment;
+	GtkWidget* frame;
+
+	frame = xfce_gtk_frame_box_new(label, &alignment);
+G_GNUC_BEGIN_IGNORE_DEPRECATIONS
+	gtk_alignment_set_padding(GTK_ALIGNMENT(alignment), 6, 0, 12, 0);
+G_GNUC_END_IGNORE_DEPRECATIONS
+	gtk_container_add(GTK_CONTAINER(alignment), GTK_WIDGET(content));
+
+	return frame;
+}
+
+//-----------------------------------------------------------------------------
+
 ConfigurationDialog::ConfigurationDialog(Plugin* plugin) :
 	m_plugin(plugin)
 {
@@ -238,14 +254,8 @@ void ConfigurationDialog::toggle_show_hierarchy(GtkToggleButton* button)
 
 void ConfigurationDialog::toggle_position_search_alternate(GtkToggleButton* button)
 {
-	bool active = gtk_toggle_button_get_active(button);
 	wm_settings->position_search_alternate = gtk_toggle_button_get_active(button);
 	wm_settings->set_modified();
-	gtk_widget_set_sensitive(GTK_WIDGET(m_position_commands_alternate), active);
-	if (!active)
-	{
-		gtk_toggle_button_set_active(GTK_TOGGLE_BUTTON(m_position_commands_alternate), false);
-	}
 }
 
 //-----------------------------------------------------------------------------
@@ -266,6 +276,22 @@ void ConfigurationDialog::toggle_position_categories_alternate(GtkToggleButton*
 
 //-----------------------------------------------------------------------------
 
+void ConfigurationDialog::toggle_stay_on_focus_out(GtkToggleButton* button)
+{
+	wm_settings->stay_on_focus_out = gtk_toggle_button_get_active(button);
+	wm_settings->set_modified();
+}
+
+//-----------------------------------------------------------------------------
+
+void ConfigurationDialog::toggle_confirm_session_command(GtkToggleButton* button)
+{
+	wm_settings->confirm_session_command = gtk_toggle_button_get_active(button);
+	wm_settings->set_modified();
+}
+
+//-----------------------------------------------------------------------------
+
 void ConfigurationDialog::recent_items_max_changed(GtkSpinButton* button)
 {
 	wm_settings->recent_items_max = gtk_spin_button_get_value_as_int(button);
@@ -517,8 +543,8 @@ void ConfigurationDialog::response(GtkDialog*, int response_id)
 GtkWidget* ConfigurationDialog::init_appearance_tab()
 {
 	// Create appearance page
-	GtkBox* page = GTK_BOX(gtk_box_new(GTK_ORIENTATION_VERTICAL, 0));
-	gtk_container_set_border_width(GTK_CONTAINER(page), 8);
+	GtkBox* page = GTK_BOX(gtk_box_new(GTK_ORIENTATION_VERTICAL, 18));
+	gtk_container_set_border_width(GTK_CONTAINER(page), 12);
 
 
 	// Create panel button section
@@ -526,9 +552,8 @@ GtkWidget* ConfigurationDialog::init_appearance_tab()
 	gtk_grid_set_column_spacing(panel_table, 12);
 	gtk_grid_set_row_spacing(panel_table, 6);
 
-	GtkWidget* panel_frame = xfce_gtk_frame_box_new_with_content(_("Panel Button"), GTK_WIDGET(panel_table));
-	gtk_box_pack_start(page, panel_frame, false, false, 6);
-	gtk_container_set_border_width(GTK_CONTAINER(panel_frame), 0);
+	GtkWidget* panel_frame = make_aligned_frame(_("Panel Button"), GTK_WIDGET(panel_table));
+	gtk_box_pack_start(page, panel_frame, false, false, 0);
 
 	// Add button style selector
 	GtkWidget* label = gtk_label_new_with_mnemonic(_("Di_splay:"));
@@ -584,9 +609,8 @@ GtkWidget* ConfigurationDialog::init_appearance_tab()
 	gtk_grid_set_column_spacing(menu_table, 12);
 	gtk_grid_set_row_spacing(menu_table, 6);
 
-	GtkWidget* appearance_frame = xfce_gtk_frame_box_new_with_content(_("Menu"), GTK_WIDGET(menu_table));
-	gtk_box_pack_start(page, appearance_frame, false, false, 6);
-	gtk_container_set_border_width(GTK_CONTAINER(appearance_frame), 0);
+	GtkWidget* appearance_frame = make_aligned_frame(_("Menu"), GTK_WIDGET(menu_table));
+	gtk_box_pack_start(page, appearance_frame, false, false, 0);
 
 	// Add option to use generic names
 	m_show_generic_names = gtk_check_button_new_with_mnemonic(_("Show generic application _names"));
@@ -609,7 +633,7 @@ GtkWidget* ConfigurationDialog::init_appearance_tab()
 
 	// Add option to hide tooltips
 	m_show_tooltips = gtk_check_button_new_with_mnemonic(_("Show application too_ltips"));
-	gtk_grid_attach(menu_table, m_show_tooltips, 0, 3, 3, 1);
+	gtk_grid_attach(menu_table, m_show_tooltips, 0, 3, 2, 1);
 	gtk_toggle_button_set_active(GTK_TOGGLE_BUTTON(m_show_tooltips), wm_settings->launcher_show_tooltip);
 	g_signal_connect_slot(m_show_tooltips, "toggled", &ConfigurationDialog::toggle_show_tooltip, this);
 
@@ -675,15 +699,14 @@ GtkWidget* ConfigurationDialog::init_appearance_tab()
 GtkWidget* ConfigurationDialog::init_behavior_tab()
 {
 	// Create behavior page
-	GtkBox* page = GTK_BOX(gtk_box_new(GTK_ORIENTATION_VERTICAL, 8));
-	gtk_container_set_border_width(GTK_CONTAINER(page), 8);
+	GtkBox* page = GTK_BOX(gtk_box_new(GTK_ORIENTATION_VERTICAL, 18));
+	gtk_container_set_border_width(GTK_CONTAINER(page), 12);
 
 
 	// Create menu section
 	GtkBox* behavior_vbox = GTK_BOX(gtk_box_new(GTK_ORIENTATION_VERTICAL, 6));
-	GtkWidget* behavior_frame = xfce_gtk_frame_box_new_with_content(_("Menu"), GTK_WIDGET(behavior_vbox));
-	gtk_box_pack_start(page, behavior_frame, false, false, 6);
-	gtk_container_set_border_width(GTK_CONTAINER(behavior_frame), 0);
+	GtkWidget* behavior_frame = make_aligned_frame(_("Menu"), GTK_WIDGET(behavior_vbox));
+	gtk_box_pack_start(page, behavior_frame, false, false, 0);
 
 	// Add option to switch categories by hovering
 	m_hover_switch_category = gtk_check_button_new_with_mnemonic(_("Switch categories by _hovering"));
@@ -701,7 +724,6 @@ GtkWidget* ConfigurationDialog::init_behavior_tab()
 	m_position_commands_alternate = gtk_check_button_new_with_mnemonic(_("Position commands next to search _entry"));
 	gtk_box_pack_start(behavior_vbox, m_position_commands_alternate, true, true, 0);
 	gtk_toggle_button_set_active(GTK_TOGGLE_BUTTON(m_position_commands_alternate), wm_settings->position_commands_alternate);
-	gtk_widget_set_sensitive(GTK_WIDGET(m_position_commands_alternate), wm_settings->position_search_alternate);
 	g_signal_connect_slot(m_position_commands_alternate, "toggled", &ConfigurationDialog::toggle_position_commands_alternate, this);
 
 	// Add option to use alternate categories position
@@ -710,15 +732,20 @@ GtkWidget* ConfigurationDialog::init_behavior_tab()
 	gtk_toggle_button_set_active(GTK_TOGGLE_BUTTON(m_position_categories_alternate), wm_settings->position_categories_alternate);
 	g_signal_connect_slot(m_position_categories_alternate, "toggled", &ConfigurationDialog::toggle_position_categories_alternate, this);
 
+	// Add option to stay when menu loses focus
+	m_stay_on_focus_out = gtk_check_button_new_with_mnemonic(_("Stay _visible when focus is lost"));
+	gtk_box_pack_start(behavior_vbox, m_stay_on_focus_out, true, true, 0);
+	gtk_toggle_button_set_active(GTK_TOGGLE_BUTTON(m_stay_on_focus_out), wm_settings->stay_on_focus_out);
+	g_signal_connect_slot(m_stay_on_focus_out, "toggled", &ConfigurationDialog::toggle_stay_on_focus_out, this);
+
 
 	// Create recently used section
 	GtkGrid* recent_table = GTK_GRID(gtk_grid_new());
 	gtk_grid_set_column_spacing(recent_table, 12);
 	gtk_grid_set_row_spacing(recent_table, 6);
 
-	GtkWidget* recent_frame = xfce_gtk_frame_box_new_with_content(_("Recently Used"), GTK_WIDGET(recent_table));
-	gtk_box_pack_start(page, recent_frame, false, false, 6);
-	gtk_container_set_border_width(GTK_CONTAINER(recent_frame), 0);
+	GtkWidget* recent_frame = make_aligned_frame(_("Recently Used"), GTK_WIDGET(recent_table));
+	gtk_box_pack_start(page, recent_frame, false, false, 0);
 
 	// Add value to change maximum number of recently used entries
 	GtkWidget* label = gtk_label_new_with_mnemonic(_("Amount of _items:"));
@@ -744,6 +771,18 @@ GtkWidget* ConfigurationDialog::init_behavior_tab()
 	gtk_widget_set_sensitive(GTK_WIDGET(m_display_recent), wm_settings->recent_items_max);
 	g_signal_connect_slot(m_display_recent, "toggled", &ConfigurationDialog::toggle_display_recent, this);
 
+
+	// Create command buttons section
+	GtkBox* command_vbox = GTK_BOX(gtk_box_new(GTK_ORIENTATION_VERTICAL, 6));
+	GtkWidget* command_frame = make_aligned_frame(_("Session Commands"), GTK_WIDGET(command_vbox));
+	gtk_box_pack_start(page, command_frame, false, false, 0);
+
+	// Add option to show confirmation dialogs
+	m_confirm_session_command = gtk_check_button_new_with_mnemonic(_("Show c_onfirmation dialog"));
+	gtk_box_pack_start(command_vbox, m_confirm_session_command, true, true, 0);
+	gtk_toggle_button_set_active(GTK_TOGGLE_BUTTON(m_confirm_session_command), wm_settings->confirm_session_command);
+	g_signal_connect_slot(m_confirm_session_command, "toggled", &ConfigurationDialog::toggle_confirm_session_command, this);
+
 	return GTK_WIDGET(page);
 }
 
@@ -752,8 +791,8 @@ GtkWidget* ConfigurationDialog::init_behavior_tab()
 GtkWidget* ConfigurationDialog::init_commands_tab()
 {
 	// Create commands page
-	GtkBox* page = GTK_BOX(gtk_box_new(GTK_ORIENTATION_VERTICAL, 8));
-	gtk_container_set_border_width(GTK_CONTAINER(page), 8);
+	GtkBox* page = GTK_BOX(gtk_box_new(GTK_ORIENTATION_VERTICAL, 6));
+	gtk_container_set_border_width(GTK_CONTAINER(page), 12);
 	GtkSizeGroup* label_size_group = gtk_size_group_new(GTK_SIZE_GROUP_HORIZONTAL);
 
 	// Add command entries
@@ -773,7 +812,7 @@ GtkWidget* ConfigurationDialog::init_search_actions_tab()
 {
 	// Create search actions page
 	GtkGrid* page = GTK_GRID(gtk_grid_new());
-	gtk_container_set_border_width(GTK_CONTAINER(page), 8);
+	gtk_container_set_border_width(GTK_CONTAINER(page), 12);
 	gtk_grid_set_column_spacing(page, 6);
 	gtk_grid_set_row_spacing(page, 6);
 
@@ -846,11 +885,10 @@ GtkWidget* ConfigurationDialog::init_search_actions_tab()
 
 	// Create details section
 	GtkGrid* details_table = GTK_GRID(gtk_grid_new());
-	gtk_grid_set_column_spacing(details_table, 6);
+	gtk_grid_set_column_spacing(details_table, 12);
 	gtk_grid_set_row_spacing(details_table, 6);
-	GtkWidget* details_frame = xfce_gtk_frame_box_new_with_content(_("Details"), GTK_WIDGET(details_table));
+	GtkWidget* details_frame = make_aligned_frame(_("Details"), GTK_WIDGET(details_table));
 	gtk_grid_attach(page, details_frame, 0, 1, 2, 1);
-	gtk_container_set_border_width(GTK_CONTAINER(details_frame), 0);
 
 	// Create entry for name
 	GtkWidget* label = gtk_label_new_with_mnemonic(_("Nam_e:"));
