@@ -1,5 +1,5 @@
 /*
- * Copyright (C) 2013, 2014, 2015, 2016, 2017, 2018 Graeme Gott <graeme@gottcode.org>
+ * Copyright (C) 2013, 2014, 2015, 2016, 2017, 2018, 2019 Graeme Gott <graeme@gottcode.org>
  *
  * This library is free software; you can redistribute it and/or modify
  * it under the terms of the GNU General Public License as published by
@@ -96,6 +96,10 @@ Plugin::Plugin(XfcePanelPlugin* plugin) :
 	// Load settings
 	wm_settings = new Settings;
 	wm_settings->button_title = get_button_title_default();
+	for (int i = Settings::CommandSwitchUser; i < Settings::CommandLogOut; ++i)
+	{
+		wm_settings->command[i]->set_shown(false);
+	}
 	wm_settings->load(xfce_resource_lookup(XFCE_RESOURCE_CONFIG, "xfce4/whiskermenu/defaults.rc"));
 	wm_settings->load(xfce_panel_plugin_lookup_rc_file(m_plugin));
 	m_opacity = wm_settings->menu_opacity;
@@ -402,7 +406,7 @@ void Plugin::show_about()
 		(NULL,
 		"authors", authors,
 		"comments", _("Alternate application launcher for Xfce"),
-		"copyright", _("Copyright \302\251 2013-2018 Graeme Gott"),
+		"copyright", _("Copyright \302\251 2013-2019 Graeme Gott"),
 		"license", XFCE_LICENSE_GPL,
 		"logo-icon-name", "xfce4-whiskermenu",
 		"program-name", PACKAGE_NAME,
