@@ -1,5 +1,5 @@
 /*
- * Copyright (C) 2013, 2014, 2015, 2016 Graeme Gott <graeme@gottcode.org>
+ * Copyright (C) 2013, 2014, 2015, 2016, 2017, 2018 Graeme Gott <graeme@gottcode.org>
  *
  * This library is free software; you can redistribute it and/or modify
  * it under the terms of the GNU General Public License as published by
@@ -36,6 +36,11 @@ static const char* const settings_command[Settings::CountCommands][2] = {
 	{ "command-settings",   "show-command-settings"   },
 	{ "command-lockscreen", "show-command-lockscreen" },
 	{ "command-switchuser", "show-command-switchuser" },
+	{ "command-logoutuser", "show-command-logoutuser" },
+	{ "command-restart",    "show-command-restart"    },
+	{ "command-shutdown",   "show-command-shutdown"   },
+	{ "command-suspend",    "show-command-suspend"    },
+	{ "command-hibernate",  "show-command-hibernate"  },
 	{ "command-logout",     "show-command-logout"     },
 	{ "command-menueditor", "show-command-menueditor" },
 	{ "command-profile",    "show-command-profile"    }
@@ -106,6 +111,9 @@ Settings::Settings() :
 	position_search_alternate(false),
 	position_commands_alternate(false),
 	position_categories_alternate(false),
+	stay_on_focus_out(false),
+
+	confirm_session_command(true),
 
 	menu_width(400),
 	menu_height(500),
@@ -116,12 +124,60 @@ Settings::Settings() :
 	favorites.push_back("exo-mail-reader.desktop");
 	favorites.push_back("exo-web-browser.desktop");
 
-	command[CommandSettings] = new Command("preferences-desktop", _("All _Settings"), "xfce4-settings-manager", _("Failed to open settings manager."));
-	command[CommandLockScreen] = new Command("system-lock-screen", _("_Lock Screen"), "xflock4", _("Failed to lock screen."));
-	command[CommandSwitchUser] = new Command("system-users", _("Switch _Users"), "gdmflexiserver", _("Failed to switch users."));
-	command[CommandLogOut] = new Command("system-log-out", _("Log _Out"), "xfce4-session-logout", _("Failed to log out."));
-	command[CommandMenuEditor] = new Command("xfce4-menueditor", _("_Edit Applications"), "menulibre", _("Failed to launch menu editor."));
-	command[CommandProfile] = new Command("avatar-default", _("Edit _Profile"), "mugshot", _("Failed to edit profile."));
+	command[CommandSettings] = new Command("preferences-desktop",
+			_("All _Settings"),
+			"xfce4-settings-manager",
+			_("Failed to open settings manager."));
+	command[CommandLockScreen] = new Command("system-lock-screen",
+			_("_Lock Screen"),
+			"xflock4",
+			_("Failed to lock screen."));
+	command[CommandSwitchUser] = new Command("system-users",
+			_("Switch _Users"),
+			"gdmflexiserver",
+			_("Failed to switch users."));
+	command[CommandLogOutUser] = new Command("system-log-out",
+			_("Log _Out"),
+			"xfce4-session-logout --logout --fast",
+			_("Failed to log out."),
+			_("Are you sure you want to log out?"),
+			_("Logging out in %d seconds."));
+	command[CommandRestart] = new Command("system-reboot",
+			_("_Restart"),
+			"xfce4-session-logout --reboot --fast",
+			_("Failed to restart."),
+			_("Are you sure you want to restart?"),
+			_("Restarting computer in %d seconds."));
+	command[CommandShutDown] = new Command("system-shutdown",
+			_("Shut _Down"),
+			"xfce4-session-logout --halt --fast",
+			_("Failed to shut down."),
+			_("Are you sure you want to shut down?"),
+			_("Turning off computer in %d seconds."));
+	command[CommandSuspend] = new Command("system-suspend",
+			_("Suspe_nd"),
+			"xfce4-session-logout --suspend",
+			_("Failed to suspend."),
+			_("Do you want to suspend to RAM?"),
+			_("Suspending computer in %d seconds."));
+	command[CommandHibernate] = new Command("system-hibernate",
+			_("_Hibernate"),
+			"xfce4-session-logout --hibernate",
+			_("Failed to hibernate."),
+			_("Do you want to suspend to disk?"),
+			_("Hibernating computer in %d seconds."));
+	command[CommandLogOut] = new Command("system-log-out",
+			_("Log Ou_t..."),
+			"xfce4-session-logout",
+			_("Failed to log out."));
+	command[CommandMenuEditor] = new Command("xfce4-menueditor",
+			_("_Edit Applications"),
+			"menulibre",
+			_("Failed to launch menu editor."));
+	command[CommandProfile] = new Command("avatar-default",
+			_("Edit _Profile"),
+			"mugshot",
+			_("Failed to edit profile."));
 
 	search_actions.push_back(new SearchAction(_("Man Pages"), "#", "exo-open --launch TerminalEmulator man %s", false, true));
 	search_actions.push_back(new SearchAction(_("Web Search"), "?", "exo-open --launch WebBrowser https://duckduckgo.com/?q=%u", false, true));
@@ -180,7 +236,7 @@ void Settings::load(char* file)
 
 	category_hover_activate = xfce_rc_read_bool_entry(rc, "hover-switch-category", category_hover_activate);
 	category_icon_size = xfce_rc_read_int_entry(rc, "category-icon-size", category_icon_size);
-	category_show_name = xfce_rc_read_bool_entry(rc, "category-show-name", category_show_name) && (category_icon_size != -1);
+	category_show_name = xfce_rc_read_bool_entry(rc, "category-show-name", category_show_name) || (category_icon_size == -1);
 
 	load_hierarchy = xfce_rc_read_bool_entry(rc, "load-hierarchy", load_hierarchy);
 
@@ -189,8 +245,11 @@ void Settings::load(char* file)
 	display_recent = xfce_rc_read_bool_entry(rc, "display-recent-default", display_recent) && recent_items_max;
 
 	position_search_alternate = xfce_rc_read_bool_entry(rc, "position-search-alternate", position_search_alternate);
-	position_commands_alternate = xfce_rc_read_bool_entry(rc, "position-commands-alternate", position_commands_alternate) && position_search_alternate;
+	position_commands_alternate = xfce_rc_read_bool_entry(rc, "position-commands-alternate", position_commands_alternate);
 	position_categories_alternate = xfce_rc_read_bool_entry(rc, "position-categories-alternate", position_categories_alternate);
+	stay_on_focus_out = xfce_rc_read_bool_entry(rc, "stay-on-focus-out", stay_on_focus_out);
+
+	confirm_session_command = xfce_rc_read_bool_entry(rc, "confirm-session-command", confirm_session_command);
 
 	menu_width = std::max(10, xfce_rc_read_int_entry(rc, "menu-width", menu_width));
 	menu_height = std::max(10, xfce_rc_read_int_entry(rc, "menu-height", menu_height));
@@ -289,6 +348,9 @@ void Settings::save(char* file)
 	xfce_rc_write_bool_entry(rc, "position-search-alternate", position_search_alternate);
 	xfce_rc_write_bool_entry(rc, "position-commands-alternate", position_commands_alternate);
 	xfce_rc_write_bool_entry(rc, "position-categories-alternate", position_categories_alternate);
+	xfce_rc_write_bool_entry(rc, "stay-on-focus-out", stay_on_focus_out);
+
+	xfce_rc_write_bool_entry(rc, "confirm-session-command", confirm_session_command);
 
 	xfce_rc_write_int_entry(rc, "menu-width", menu_width);
 	xfce_rc_write_int_entry(rc, "menu-height", menu_height);
