@@ -42,6 +42,11 @@ using namespace WhiskerMenu;
 
 static void grab_pointer(GtkWidget* widget)
 {
+	if (wm_settings->stay_on_focus_out)
+	{
+		return;
+	}
+
 	GdkDisplay* display = gdk_display_get_default();
 	GdkSeat* seat = gdk_display_get_default_seat(display);
 	GdkWindow* window = gtk_widget_get_window(widget);
@@ -50,6 +55,11 @@ static void grab_pointer(GtkWidget* widget)
 
 static void ungrab_pointer()
 {
+	if (wm_settings->stay_on_focus_out)
+	{
+		return;
+	}
+
 	GdkDisplay* display = gdk_display_get_default();
 	GdkSeat* seat = gdk_display_get_default_seat(display);
 	gdk_seat_ungrab(seat);
@@ -128,12 +138,9 @@ WhiskerMenu::Window::Window(Plugin* plugin) :
 	g_free(username);
 
 	// Create action buttons
-	m_commands_button[0] = wm_settings->command[Settings::CommandSettings]->get_button();
-	m_commands_button[1] = wm_settings->command[Settings::CommandLockScreen]->get_button();
-	m_commands_button[2] = wm_settings->command[Settings::CommandSwitchUser]->get_button();
-	m_commands_button[3] = wm_settings->command[Settings::CommandLogOut]->get_button();
-	for (int i = 0; i < 4; ++i)
+	for (int i = 0; i < 9; ++i)
 	{
+		m_commands_button[i] = wm_settings->command[i]->get_button();
 		m_command_slots[i] = g_signal_connect_slot<GtkButton*>(m_commands_button[i], "clicked", &Window::hide, this);
 	}
 
@@ -185,7 +192,7 @@ WhiskerMenu::Window::Window(Plugin* plugin) :
 	m_commands_box = GTK_BOX(gtk_box_new(GTK_ORIENTATION_HORIZONTAL, 0));
 	m_commands_spacer = gtk_label_new(NULL);
 	gtk_box_pack_start(m_commands_box, m_commands_spacer, true, true, 0);
-	for (int i = 0; i < 4; ++i)
+	for (int i = 0; i < 9; ++i)
 	{
 		gtk_box_pack_start(m_commands_box, m_commands_button[i], false, false, 0);
 	}
@@ -257,7 +264,7 @@ WhiskerMenu::Window::Window(Plugin* plugin) :
 
 WhiskerMenu::Window::~Window()
 {
-	for (int i = 0; i < 4; ++i)
+	for (int i = 0; i < 9; ++i)
 	{
 		g_signal_handler_disconnect(m_commands_button[i], m_command_slots[i]);
 		gtk_container_remove(GTK_CONTAINER(m_commands_box), m_commands_button[i]);
@@ -288,7 +295,7 @@ void WhiskerMenu::Window::hide()
 	unset_pressed_category();
 
 	// Hide command buttons to remove active border
-	for (int i = 0; i < 4; ++i)
+	for (int i = 0; i < 9; ++i)
 	{
 		gtk_widget_set_visible(m_commands_button[i], false);
 	}
@@ -476,13 +483,6 @@ void WhiskerMenu::Window::show(const Position position)
 		g_object_ref(m_commands_box);
 		if (m_layout_commands_alternate)
 		{
-			if (!m_sidebar_size_group)
-			{
-				m_sidebar_size_group = gtk_size_group_new(GTK_SIZE_GROUP_HORIZONTAL);
-				gtk_size_group_add_widget(m_sidebar_size_group, GTK_WIDGET(m_sidebar));
-				gtk_size_group_add_widget(m_sidebar_size_group, GTK_WIDGET(m_commands_box));
-			}
-
 			gtk_container_remove(GTK_CONTAINER(m_title_box), GTK_WIDGET(m_commands_box));
 			gtk_box_pack_start(m_search_box, GTK_WIDGET(m_commands_box), false, false, 0);
 		}
@@ -502,6 +502,23 @@ void WhiskerMenu::Window::show(const Position position)
 		g_object_unref(m_commands_box);
 	}
 
+	if (m_layout_commands_alternate)
+	{
+		if (!m_sidebar_size_group && wm_settings->category_show_name)
+		{
+			m_sidebar_size_group = gtk_size_group_new(GTK_SIZE_GROUP_HORIZONTAL);
+			gtk_size_group_add_widget(m_sidebar_size_group, GTK_WIDGET(m_sidebar));
+			gtk_size_group_add_widget(m_sidebar_size_group, GTK_WIDGET(m_commands_box));
+		}
+		else if (m_sidebar_size_group && !wm_settings->category_show_name)
+		{
+			gtk_size_group_remove_widget(m_sidebar_size_group, GTK_WIDGET(m_sidebar));
+			gtk_size_group_remove_widget(m_sidebar_size_group, GTK_WIDGET(m_commands_box));
+			g_object_unref(m_sidebar_size_group);
+			m_sidebar_size_group = NULL;
+		}
+	}
+
 	if ((layout_left && !wm_settings->position_categories_alternate)
 			|| (!layout_left && wm_settings->position_categories_alternate))
 	{
@@ -533,7 +550,7 @@ void WhiskerMenu::Window::show(const Position position)
 		{
 			gtk_widget_set_halign(GTK_WIDGET(m_username), GTK_ALIGN_START);
 
-			for (int i = 0; i < 4; ++i)
+			for (int i = 0; i < 9; ++i)
 			{
 				gtk_box_reorder_child(m_commands_box, m_commands_button[i], i);
 			}
@@ -547,9 +564,9 @@ void WhiskerMenu::Window::show(const Position position)
 		{
 			gtk_widget_set_halign(GTK_WIDGET(m_username), GTK_ALIGN_END);
 
-			for (int i = 0; i < 4; ++i)
+			for (int i = 0; i < 9; ++i)
 			{
-				gtk_box_reorder_child(m_commands_box, m_commands_button[i], 3 - i);
+				gtk_box_reorder_child(m_commands_box, m_commands_button[i], 8 - i);
 			}
 			gtk_box_reorder_child(m_commands_box, m_commands_spacer, 4);
 
@@ -561,7 +578,7 @@ void WhiskerMenu::Window::show(const Position position)
 		{
 			gtk_widget_set_halign(GTK_WIDGET(m_username), GTK_ALIGN_START);
 
-			for (int i = 0; i < 4; ++i)
+			for (int i = 0; i < 9; ++i)
 			{
 				gtk_box_reorder_child(m_commands_box, m_commands_button[i], i);
 			}
@@ -576,9 +593,9 @@ void WhiskerMenu::Window::show(const Position position)
 		{
 			gtk_widget_set_halign(GTK_WIDGET(m_username), GTK_ALIGN_END);
 
-			for (int i = 0; i < 4; ++i)
+			for (int i = 0; i < 9; ++i)
 			{
-				gtk_box_reorder_child(m_commands_box, m_commands_button[i], 3 - i);
+				gtk_box_reorder_child(m_commands_box, m_commands_button[i], 8 - i);
 			}
 			gtk_box_reorder_child(m_commands_box, m_commands_spacer, 4);
 
@@ -750,6 +767,11 @@ gboolean WhiskerMenu::Window::on_leave_notify_event(GtkWidget*, GdkEvent* event)
 
 gboolean WhiskerMenu::Window::on_button_press_event(GtkWidget*, GdkEvent* event)
 {
+	if (wm_settings->stay_on_focus_out)
+	{
+		return false;
+	}
+
 	// Hide menu if user clicks outside
 	GdkEventButton* button_event = reinterpret_cast<GdkEventButton*>(event);
 	if ((button_event->x_root <= m_geometry.x)
